@@ -40,10 +40,10 @@ def sql(key):
             'sql': "select collectorId from JDBCCollectorConfig where JDBCCollectorConfig.type='mysqljdbc' AND JDBCCollectorConfig.`sql`='select * from AgentHost';",
             'database': 'AnyRobot'},
         'vSphereID': {
-            'sql': "SELECT collectorId FROM CollectorConfig WHERE collectorType='vSphere' AND config LIKE '%192.168.0.250%';",
+            'sql': "SELECT collectorId FROM CollectorConfig WHERE collectorType='vSphere' AND config LIKE '%hlaio.aishu.cn%';",
             'database': 'AnyRobot'},
         'vcenterCollectorId': {
-            'sql': "SELECT collectorId FROM CollectorConfig WHERE collectorType='vCenter' AND config LIKE '%192.168.0.250%';",
+            'sql': "SELECT collectorId FROM CollectorConfig WHERE collectorType='vCenter' AND config LIKE '%hlaio.aishu.cn%';",
             'database': 'AnyRobot'},
         'MySQLCollectorId': {'sql': "SELECT collectorId FROM CollectorConfig WHERE collectorType='MySQL Performance';",
                              'database': 'AnyRobot'},
@@ -93,7 +93,7 @@ def sql(key):
         'ReprotIdDisable': {'sql': "SELECT report_id From report WHERE is_share_allowed = 0;", 'database': 'AnyRobot'},
         'ReprotName': {'sql': "SELECT `name` From report ;", 'database': 'AnyRobot'},
         'ReprotType': {'sql': "SELECT `type` From report ;", 'database': 'AnyRobot'},
-
+        'CorrelationSearchesId': {'sql': "SELECT `id` From correlate_search ;", 'database': 'AnyRobot'}
     }
 
     if switcher.get(key) is not None:
